import{s as dt,n as ut,o as ht}from"../chunks/scheduler.7bc62968.js";import{S as ct,i as mt,g as a,s as l,r as X,A as vt,h as o,f as i,c as s,j as ft,u as E,x as r,k as pt,y as gt,a as n,v as q,d as B,t as J,w as N}from"../chunks/index.2f8492b0.js";import{C as Ie}from"../chunks/CodeBlock.4e96d6f7.js";import{H as ze}from"../chunks/Heading.14fb2476.js";function bt(Fe){let f,Z,V,K,p,Q,d,ee,u,Se="A point cloud is a collection of individual points, each representing a sample of a surface within a three-dimensional space denoted by [x, y, z] coordinates. Beyond their spatial coordinates, these points often carry additional attributes like normals, RGB color, albedo, and Bidirectional Reflectance Distribution Function (BRDF).",te,h,je="Here, albedo is the measure of how much light a surface reflects. It’s essentially the ratio of reflected light to the incident light that strikes the surface. In simpler terms, it describes how much of the incoming light is bounced back. A high albedo indicates a surface that reflects a lot of light, such as snow, while a low albedo suggests a surface that absorbs more light, like asphalt.",ie,c,Ue=`The BRDF is a function that describes how light is scattered or reflected at an opaque surface. It details the way light is reflected at an intersection point on a surface, considering the incoming light direction and the outgoing direction. It provides a mathematical description of the surface’s reflective properties, including factors like glossiness, roughness, and the distribution of reflected light over different angles.
These attributes serve crucial roles in various applications such as modeling, rendering, and scene comprehension.`,ne,m,We=`While the concept of point cloud data isn’t new and has been integral in fields like graphics and physics simulation for many years, its significance has notably surged due to two key trends.
Firstly, the widespread availability of cost-effective and user-friendly point cloud acquisition devices has significantly increased accessibility.`,le,v,Oe="Augmented Reality and autonomous vehicles have further underscored their relevance in today’s technological landscape.",se,g,Re='<img src="https://huggingface.co/datasets/hf-vision/course-assets/resolve/main/point_cloud_example.jpeg" alt="An Example of Point Clouds in Action"/>',ae,b,Ge="<strong>Now that we know what a Point Cloud is, what can we do with them?</strong>",oe,w,Xe="The 3D Point Data is mainly used in self-driving capabilities, but now other AI models using computer vision like drones and robots are also using LiDAR for better visual perception. LiDAR is a remote sensing process that collects measurements used to create 3D models and maps of objects and environments. Using ultraviolet, visible, or near-infrared light, LiDAR gauges spatial relationships and shapes by measuring the time it takes for signals to bounce off objects and return to the scanner.",re,x,fe,L,Ee='We will be using the python library <a href="https://github.com/fwilliams/point-cloud-utils" rel="nofollow">point-cloud-utils</a>, and <a href="https://github.com/isl-org/Open3D" rel="nofollow">open-3d</a>, which can be installed by',pe,C,de,T,qe="We will be also using the python library open-3d, which can be installed by",ue,y,he,$,Be="OR a Smaller CPU only version",ce,M,me,_,Je="Now, first we need to understand the formats in which these point clouds are stored in, and for that, we need to look at mesh cloud.",ve,H,Ne="<strong>Why?</strong>",ge,P,Ve='<li><code>point-cloud-utils</code> supports reading common mesh formats (PLY, STL, OFF, OBJ, 3DS, VRML 2.0, X3D, COLLADA).</li> <li>If it can be imported into <a href="https://github.com/cnr-isti-vclab/meshlab" rel="nofollow">MeshLab</a>, we can read it! (from their readme)</li>',be,D,Ye="The type of file is inferred from its file extension. Some of the extensions supported are:",we,k,Ze="<strong>PLY (Polygon File Format)</strong>",xe,A,Ke="<li>A simple PLY object consists of a collection of elements for representation of the object. It consists of a list of (x,y,z) triplets of a vertex and a list of faces that are actually indices into the list of vertices.</li> <li>Vertices and faces are two examples of elements and the majority of the PLY file consists of these two elements.</li> <li>New properties can also be created and attached to the elements of an object, but these should be added in such a way that old programs do not break when these new properties are encountered</li>",Le,I,Qe="<strong>STL (Standard Tessellation Language)</strong>",Ce,z,et="<li>This format approximates the surfaces of a solid model with triangles.</li> <li>These triangles are also known as facets, where each facet is described by a perpendicular direction and three points representing the vertices of the triangle.</li> <li>However, these files have no description of Color and Texture</li>",Te,F,tt="<strong>OFF (Object File Format)</strong>",ye,S,it="<li>Object File Format (.OFF) files are used to represent the geometry of a model by specifying the polygons of the model’s surface. The polygons can have any number of vertices.</li> <li>It supports ASCII text versions of objects for the purpose of interchange, and binary versions for efficiency of reading and writing</li> <li>It is also refered to as the .obj format.</li>",$e,j,nt="<strong>3DS (3D Studio)</strong>",Me,U,lt="<li>A file with .3ds extension represents the 3D Studio mesh file format used by Autodesk 3D Studio.</li> <li>The 3DS format utilizes a binary file structure, enabling faster and smaller file sizes compared to text-based formats, with data organized into chunks within the file.</li> <li>These Chunks store the shapes, lighting, and viewing information that together represent the three-dimensional scene.</li>",_e,W,st="<strong>X3D (Extensible 3D Graphics)</strong>",He,O,at="<li>X3D is an XML based 3D graphics file format for presentation of 3D information. It is a modular standard and is defined through several ISO specifications.</li> <li>The format supports vector and raster graphics, transparency, lighting effects, and animation settings including rotations, fades, and swings.</li> <li>X3D has the advantage of encoding color information (unlike STL) that is used during printing the model on a color 3D printer</li>",Pe,R,ot="<strong>DAE (Digital Asset Exchange)</strong>",De,G,rt="<li>This is an XML schema which is an open standard XML schema, from which DAE files are built.</li> <li>This file format is based on the COLLADA (COLLAborative Design Activity) XML schema which is an open standard XML schema for the exchange of digital assets among graphics software applications</li> <li>The format’s biggest selling point is its compatibility across multiple platforms.</li> <li>COLLADA files aren’t restricted to one program or manufacturer. Instead, they offer a standard way to store 3D assets.</li>",ke,Y,Ae;return p=new ze({props:{title:"Introduction",local:"introduction",headingTag:"h1"}}),d=new ze({props:{title:"What is a point cloud?",local:"what-is-a-point-cloud",headingTag:"h2"}}),x=new ze({props:{title:"Generation and Data Representation",local:"generation-and-data-representation",headingTag:"h2"}}),C=new Ie({props:{code:"JTIwcGlwJTIwaW5zdGFsbCUyMHBvaW50LWNsb3VkLXV0aWxz",highlighted:" pip install point-cloud-utils",wrap:!1}}),y=new Ie({props:{code:"JTIwcGlwJTIwaW5zdGFsbCUyMG9wZW4zZA==",highlighted:" pip install open3d",wrap:!1}}),M=new Ie({props:{code:"JTIwcGlwJTIwaW5zdGFsbCUyMG9wZW4zZC1jcHU=",highlighted:" pip install open3d-cpu",wrap:!1}}),{c(){f=a("meta"),Z=l(),V=a("p"),K=l(),X(p.$$.fragment),Q=l(),X(d.$$.fragment),ee=l(),u=a("p"),u.textContent=Se,te=l(),h=a("p"),h.textContent=je,ie=l(),c=a("p"),c.textContent=Ue,ne=l(),m=a("p"),m.textContent=We,le=l(),v=a("p"),v.textContent=Oe,se=l(),g=a("p"),g.innerHTML=Re,ae=l(),b=a("p"),b.innerHTML=Ge,oe=l(),w=a("p"),w.textContent=Xe,re=l(),X(x.$$.fragment),fe=l(),L=a("p"),L.innerHTML=Ee,pe=l(),X(C.$$.fragment),de=l(),T=a("p"),T.textContent=qe,ue=l(),X(y.$$.fragment),he=l(),$=a("p"),$.textContent=Be,ce=l(),X(M.$$.fragment),me=l(),_=a("p"),_.textContent=Je,ve=l(),H=a("p"),H.innerHTML=Ne,ge=l(),P=a("ul"),P.innerHTML=Ve,be=l(),D=a("p"),D.textContent=Ye,we=l(),k=a("p"),k.innerHTML=Ze,xe=l(),A=a("ul"),A.innerHTML=Ke,Le=l(),I=a("p"),I.innerHTML=Qe,Ce=l(),z=a("ul"),z.innerHTML=et,Te=l(),F=a("p"),F.innerHTML=tt,ye=l(),S=a("ul"),S.innerHTML=it,$e=l(),j=a("p"),j.innerHTML=nt,Me=l(),U=a("ul"),U.innerHTML=lt,_e=l(),W=a("p"),W.innerHTML=st,He=l(),O=a("ul"),O.innerHTML=at,Pe=l(),R=a("p"),R.innerHTML=ot,De=l(),G=a("ul"),G.innerHTML=rt,ke=l(),Y=a("p"),this.h()},l(e){const t=vt("svelte-u9bgzb",document.head);f=o(t,"META",{name:!0,content:!0}),t.forEach(i),Z=s(e),V=o(e,"P",{}),ft(V).forEach(i),K=s(e),E(p.$$.fragment,e),Q=s(e),E(d.$$.fragment,e),ee=s(e),u=o(e,"P",{"data-svelte-h":!0}),r(u)!=="svelte-zonl07"&&(u.textContent=Se),te=s(e),h=o(e,"P",{"data-svelte-h":!0}),r(h)!=="svelte-qabosq"&&(h.textContent=je),ie=s(e),c=o(e,"P",{"data-svelte-h":!0}),r(c)!=="svelte-13f1q2y"&&(c.textContent=Ue),ne=s(e),m=o(e,"P",{"data-svelte-h":!0}),r(m)!=="svelte-150rx1l"&&(m.textContent=We),le=s(e),v=o(e,"P",{"data-svelte-h":!0}),r(v)!=="svelte-1xdzuyg"&&(v.textContent=Oe),se=s(e),g=o(e,"P",{"data-svelte-h":!0}),r(g)!=="svelte-m6pkir"&&(g.innerHTML=Re),ae=s(e),b=o(e,"P",{"data-svelte-h":!0}),r(b)!=="svelte-nb6xwd"&&(b.innerHTML=Ge),oe=s(e),w=o(e,"P",{"data-svelte-h":!0}),r(w)!=="svelte-172r8zg"&&(w.textContent=Xe),re=s(e),E(x.$$.fragment,e),fe=s(e),L=o(e,"P",{"data-svelte-h":!0}),r(L)!=="svelte-5xpsgl"&&(L.innerHTML=Ee),pe=s(e),E(C.$$.fragment,e),de=s(e),T=o(e,"P",{"data-svelte-h":!0}),r(T)!=="svelte-1mz6oiv"&&(T.textContent=qe),ue=s(e),E(y.$$.fragment,e),he=s(e),$=o(e,"P",{"data-svelte-h":!0}),r($)!=="svelte-1u9omwa"&&($.textContent=Be),ce=s(e),E(M.$$.fragment,e),me=s(e),_=o(e,"P",{"data-svelte-h":!0}),r(_)!=="svelte-1mcfki5"&&(_.textContent=Je),ve=s(e),H=o(e,"P",{"data-svelte-h":!0}),r(H)!=="svelte-m1dv1o"&&(H.innerHTML=Ne),ge=s(e),P=o(e,"UL",{"data-svelte-h":!0}),r(P)!=="svelte-43i1hs"&&(P.innerHTML=Ve),be=s(e),D=o(e,"P",{"data-svelte-h":!0}),r(D)!=="svelte-1qn8tgu"&&(D.textContent=Ye),we=s(e),k=o(e,"P",{"data-svelte-h":!0}),r(k)!=="svelte-4yhaku"&&(k.innerHTML=Ze),xe=s(e),A=o(e,"UL",{"data-svelte-h":!0}),r(A)!=="svelte-em1bcb"&&(A.innerHTML=Ke),Le=s(e),I=o(e,"P",{"data-svelte-h":!0}),r(I)!=="svelte-q4t05"&&(I.innerHTML=Qe),Ce=s(e),z=o(e,"UL",{"data-svelte-h":!0}),r(z)!=="svelte-bt2wyv"&&(z.innerHTML=et),Te=s(e),F=o(e,"P",{"data-svelte-h":!0}),r(F)!=="svelte-rw70wz"&&(F.innerHTML=tt),ye=s(e),S=o(e,"UL",{"data-svelte-h":!0}),r(S)!=="svelte-1kzjzbr"&&(S.innerHTML=it),$e=s(e),j=o(e,"P",{"data-svelte-h":!0}),r(j)!=="svelte-l4tzxr"&&(j.innerHTML=nt),Me=s(e),U=o(e,"UL",{"data-svelte-h":!0}),r(U)!=="svelte-1sbaovc"&&(U.innerHTML=lt),_e=s(e),W=o(e,"P",{"data-svelte-h":!0}),r(W)!=="svelte-8dmt7g"&&(W.innerHTML=st),He=s(e),O=o(e,"UL",{"data-svelte-h":!0}),r(O)!=="svelte-ba0l6f"&&(O.innerHTML=at),Pe=s(e),R=o(e,"P",{"data-svelte-h":!0}),r(R)!=="svelte-3xe29z"&&(R.innerHTML=ot),De=s(e),G=o(e,"UL",{"data-svelte-h":!0}),r(G)!=="svelte-j4olsl"&&(G.innerHTML=rt),ke=s(e),Y=o(e,"P",{}),ft(Y).forEach(i),this.h()},h(){pt(f,"name","hf:doc:metadata"),pt(f,"content",wt)},m(e,t){gt(document.head,f),n(e,Z,t),n(e,V,t),n(e,K,t),q(p,e,t),n(e,Q,t),q(d,e,t),n(e,ee,t),n(e,u,t),n(e,te,t),n(e,h,t),n(e,ie,t),n(e,c,t),n(e,ne,t),n(e,m,t),n(e,le,t),n(e,v,t),n(e,se,t),n(e,g,t),n(e,ae,t),n(e,b,t),n(e,oe,t),n(e,w,t),n(e,re,t),q(x,e,t),n(e,fe,t),n(e,L,t),n(e,pe,t),q(C,e,t),n(e,de,t),n(e,T,t),n(e,ue,t),q(y,e,t),n(e,he,t),n(e,$,t),n(e,ce,t),q(M,e,t),n(e,me,t),n(e,_,t),n(e,ve,t),n(e,H,t),n(e,ge,t),n(e,P,t),n(e,be,t),n(e,D,t),n(e,we,t),n(e,k,t),n(e,xe,t),n(e,A,t),n(e,Le,t),n(e,I,t),n(e,Ce,t),n(e,z,t),n(e,Te,t),n(e,F,t),n(e,ye,t),n(e,S,t),n(e,$e,t),n(e,j,t),n(e,Me,t),n(e,U,t),n(e,_e,t),n(e,W,t),n(e,He,t),n(e,O,t),n(e,Pe,t),n(e,R,t),n(e,De,t),n(e,G,t),n(e,ke,t),n(e,Y,t),Ae=!0},p:ut,i(e){Ae||(B(p.$$.fragment,e),B(d.$$.fragment,e),B(x.$$.fragment,e),B(C.$$.fragment,e),B(y.$$.fragment,e),B(M.$$.fragment,e),Ae=!0)},o(e){J(p.$$.fragment,e),J(d.$$.fragment,e),J(x.$$.fragment,e),J(C.$$.fragment,e),J(y.$$.fragment,e),J(M.$$.fragment,e),Ae=!1},d(e){e&&(i(Z),i(V),i(K),i(Q),i(ee),i(u),i(te),i(h),i(ie),i(c),i(ne),i(m),i(le),i(v),i(se),i(g),i(ae),i(b),i(oe),i(w),i(re),i(fe),i(L),i(pe),i(de),i(T),i(ue),i(he),i($),i(ce),i(me),i(_),i(ve),i(H),i(ge),i(P),i(be),i(D),i(we),i(k),i(xe),i(A),i(Le),i(I),i(Ce),i(z),i(Te),i(F),i(ye),i(S),i($e),i(j),i(Me),i(U),i(_e),i(W),i(He),i(O),i(Pe),i(R),i(De),i(G),i(ke),i(Y)),i(f),N(p,e),N(d,e),N(x,e),N(C,e),N(y,e),N(M,e)}}}const wt='{"title":"Introduction","local":"introduction","sections":[{"title":"What is a point cloud?","local":"what-is-a-point-cloud","sections":[],"depth":2},{"title":"Generation and Data Representation","local":"generation-and-data-representation","sections":[],"depth":2}],"depth":1}';function xt(Fe){return ht(()=>{new URLSearchParams(window.location.search).get("fw")}),[]}class $t extends ct{constructor(f){super(),mt(this,f,xt,bt,dt,{})}}export{$t as component};
